# GS PY Config

Configuration class

![Python package](https://github.com/guionardo/py-config/workflows/Python%20package/badge.svg)
[![codecov](https://codecov.io/gh/guionardo/py-config/branch/develop/graph/badge.svg)](https://codecov.io/gh/guionardo/py-config)
